pygeodesy.triaxials.conformal3

Package pygeodesy :: Package triaxials :: Module conformal3 |
[frames] | no frames]

# Module conformal3

Jacobi Conformal projection classes Conformal3, Conformal3B and Conformal3Sphere on triaxial ellipsoids and spheres using Ang, Deg, Rad lat-, longitude, heading and meridian (convergence) angles.

Transcoded to pure Python from Karney's GeographicLib 2.7 C++ class Conformal3.

Copyright (C) Charles Karney (2024-2025) and licensed under the MIT/X11 License. For more information, see the GeographicLib 2.7 documentation.

Version: 26.02.15

Classes
| Conformal5Tuple 5-Tuple `(x, y, z, scale, llk)` with the easting `x` and northing `y` projection, `scale` or `NAN` but with `z=INT0` and kind `llk=LLK.CONFORMAL` always.
| BetOmgGam5Tuple 5-Tuple `(bet, omg, gam, scale, llk)` with ellipsoidal lat- `bet`, longitude `omg` and meridian convergence `gam` all Angles, `scale` and kind `llk` set to `LLK.CONFORMAL`.
| Conformal3 Jacobi Conformal projection of triaxial ellipsoid using class Ang lat- and longitudes.
| Conformal3B Jacobi Conformal projection on a triaxial ellipsoid specified by its middle semi-axis and shape.
| Conformal3Sphere Jacobi Conformal projection on a spherical triaxial.

Variables
| __all__ = `_ALL_LAZY.triaxials_conformal3`
| c = `6378137*(1-1/(298257223563/ 1000000000))`
| T = `Conformal3(6378172, 6378102, c)`
| t = `T.reverseBetOmg(* t [: 2], M= True)`